@@ -109,14 +109,15 @@ def load_parser(client, parser):
         if mode.is_origin_remote():
             remote_client.load_ssh_client_origin()
         else:
-            remote_utility.run_before_script(client)
+            helper.run_script(client, 'before')
     else:
         if mode.is_target_remote():
             remote_client.load_ssh_client_target()
         else:
-            remote_utility.run_before_script(client)
+            helper.run_script(client, 'before')
 
-    if not helper.check_file_exists(client, _path):
+    # Check only if database configuration is a file
+    if not helper.check_file_exists(client, _path) and _path[-1] is not '/':
         sys.exit(
             output.message(
                 output.Subject.ERROR,
